InvalidResponseKind

Enum InvalidResponseKind 

#[non_exhaustive]
pub enum InvalidResponseKind { TrailingBytes, FunctionMismatch, EchoMismatch, PayloadLengthMismatch, PayloadTruncated, Other(&'static str), }
Describes why a Modbus response was considered invalid.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TrailingBytes

Extra bytes remain after decoding the response PDU.



FunctionMismatch

The response function code does not match the request.



EchoMismatch

A write response did not echo the expected address/value.



PayloadLengthMismatch

The response byte count does not match the requested quantity.



PayloadTruncated

The response payload was shorter than expected.



Other(&'static str)

Catch-all for other validation failures.